function mxf_decomp_data, structure, stream, comp_code=comp_code, $
			  infile=infile
;+
;   Name: mxf_datadecomp, structure, stream
;
;   Purpose: convert fits extension header and byte stream to image
;
;   History:
;      1-Nov-1997 - S.L.Freeland - originally for TRACE, but...
;      2-Mar-1998 - S.L.Freeland - enable standard decoder
;
;   TODO - allow comp_code as keyword (dont require structure?)
;-
debug=get_logenv('trace_debug') ne ''

if not data_chk(structure,/struct) or n_params() lt 2 then begin
   prstr,strjustify(["Need structure and stream data..",$
	  "IDL> image=mxf_decomp_data(structure,stream)"],/box)
   return,-1
endif

; ------- check verify fields required by decomp routines -------
if keyword_set(comp_code) then compcode = comp_code else $
        compcode=gt_tagval(structure,/comp_code,found=ccf)
dtype   =gt_tagval(structure,/data_type,found=dtf)
nxout   =gt_tagval(structure,/nx_out,found=nxf)
nyout   =gt_tagval(structure,/ny_out,found=nyf)
; ----------------------------------------------------------------
ok= keyword_set(comp_code) or (ccf and dtf and nxf and nyf)

if not ok then begin
   prstr,strjustify(["Structure requires tags: ",$
	   "   COMP_CODE, DATA_TYPE, NX_OUT, and NY_OUT"],/box)
   return,-1
endif
; ----------------------------------------------------------------

case compcode of
   0: begin
         image=stream
         host_to_ieee, image, idltype=dtype
      endelse
      1: image=trace_jpeg_decomp(structure,stream)
   else: image=make_array(nxout,nyout,type=dtype)+fix(structure.img_max)
endcase   

return,image
end
